Struct Parser

struct Parser<C = DefaultCharAccumulator> { ... }

Parser for raw VTE protocol which delegates actions to a Perform

Implementations

impl<C> Parser<C>

fn new() -> Parser

Create a new Parser

fn advance<P: Perform>(self: &mut Self, performer: &mut P, byte: u8)

Advance the parser state

Requires a Perform in case byte triggers an action

impl<C> Freeze for Parser<C>

impl<C> RefUnwindSafe for Parser<C>

impl<C> Send for Parser<C>

impl<C> StructuralPartialEq for Parser<C>

impl<C> Sync for Parser<C>

impl<C> Unpin for Parser<C>

impl<C> UnsafeUnpin for Parser<C>

impl<C> UnwindSafe for Parser<C>

impl<C: $crate::clone::Clone> Clone for Parser<C>

fn clone(self: &Self) -> Parser<C>

impl<C: $crate::cmp::Eq> Eq for Parser<C>

impl<C: $crate::cmp::PartialEq> PartialEq for Parser<C>

fn eq(self: &Self, other: &Parser<C>) -> bool

impl<C: $crate::default::Default> Default for Parser<C>

fn default() -> Parser<C>

impl<C: $crate::fmt::Debug> Debug for Parser<C>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for Parser<C>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Parser<C>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Parser<C>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Parser<C>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Parser<C>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Parser<C>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Parser<C>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Parser<C>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Parser<C>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>